@@ -1,5 +1,5 @@
 /*
-	<<libnet.c>>
+	<libnet.c>>
 ңУǺץ
 	 ꥨ ͥåȥңУǥ <ͥåȥط饤֥>
 	 Version 0.001, October 2000
@@ -84,7 +84,7 @@ int revint(char * from){
 
 /*komment*/
 void brakepipe(int data){
-	rpglog (RPGDEBUGLEVEL ,"get broken pipe\n");
+	rpglog (RPGDEBUGLEVEL ,"libnet:get broken pipe\n");
 	/*ïΥʥ뤫Ϥ狼ʤҤȤޤfʤˤ⤷ʤ*/
 	/*Υ顼Ǥ롣*/
 
@@ -94,10 +94,10 @@ void brakepipe(int data){
 
 void  rpg_childdeth(int data){
 struct rusage rusage;
-	rpglog(RPGDEBUGLEVEL , "RPG NET LIB:Is child prosess die?\n");
+	rpglog(RPGDEBUGLEVEL , "libnet:Is child prosess die?\n");
 	wait3(NULL, WNOHANG,&rusage);	/*ҥץ򤫤ƥӤˤʤʤ褦ˤ*/
 	if (signal (SIGCHLD , rpg_childdeth) == SIG_ERR){/*ʥľ*/
-		rpglog ( RPGDEBUGLEVEL , "RPG NET LIB:Set signal error\n");
+		rpglog ( RPGDEBUGLEVEL , "libnet:Set signal error\n");
 		exit (1);
 	}
 	return ;
@@ -109,7 +109,7 @@ void rpg_endproc(int data){
 	/*줬ʤȡåȤĤäƤޤʥФ
 	äƤ⥽åȤХɤǤʤ*/
 	/*Ǥ⤦ޤʤ*/
-	rpglog(RPGDEBUGLEVEL , "RPG NET LIB:Got end signal or got end request \n");
+	rpglog(RPGDEBUGLEVEL , "libnet:Got end signal or got end request \n");
 	/*˻ҥץʤɤ˽λΤｪλƱƤ餦Τɤ*/
 
 	/*ƤΣƣĤĤ*/
@@ -124,6 +124,7 @@ void rpg_endproc(int data){
 	if (rpg_UDPAD != NULL){free (rpg_UDPAD);rpg_UDPAD= NULL;}
 	
 	RPG_shm_detach();
+	rpg_mallclose();
 	exit (1);
 }
 /*
@@ -277,33 +278,33 @@ int cnt;
 		rpg_fdnom = 0;
 		/*ѥפ»ƥХåؿ򥻥åȤ롣*/
 		if (signal (SIGPIPE , brakepipe) == SIG_ERR){
-			rpglog ( RPGDEBUGLEVEL , "RPG NET LIB:Set signal errror\n");
+			rpglog ( RPGDEBUGLEVEL , "libnet:Set signal errror\n");
 			exit (1);
 		}
 		/*ҥץȤӲΤɤ
 			ҥץȤȤϥ(wait3)ư
 			Ʊˡ̵¥֥åδ⤢ΤǤϼʤ*/
 		if (signal (SIGCHLD , rpg_childdeth) == SIG_ERR){
-			rpglog ( RPGDEBUGLEVEL , "RPG NET LIB:Set signal errror\n");
+			rpglog ( RPGDEBUGLEVEL , "libnet:Set signal errror\n");
 			exit (1);
 		}
 		/*λʥ˥åȤ򥯥򤹤롢Ĥεư
 		åȤΥХɤ򤹤ˤǤ褦ˡʤʤɤС*/
 #if 1
 		if (signal (SIGHUP , rpg_endproc) == SIG_ERR){
-			rpglog ( RPGDEBUGLEVEL , "RPG NET LIB:Set signal errror\n");
+			rpglog ( RPGDEBUGLEVEL , "libnet:Set signal errror\n");
 			exit (1);
 		}
 		if (signal (SIGTERM , rpg_endproc) == SIG_ERR){
-			rpglog ( RPGDEBUGLEVEL , "RPG NET LIB:Set signal errror\n");
+			rpglog ( RPGDEBUGLEVEL , "libnet:Set signal errror\n");
 			exit (1);
 		}
 		if (signal (SIGQUIT , rpg_endproc) == SIG_ERR){
-			rpglog ( RPGDEBUGLEVEL , "RPG NET LIB:Set signal errror\n");
+			rpglog ( RPGDEBUGLEVEL , "libnet:Set signal errror\n");
 			exit (1);
 		}
 		if (signal (SIGINT , rpg_endproc) == SIG_ERR){
-			rpglog ( RPGDEBUGLEVEL , "RPG NET LIB:Set signal errror\n");
+			rpglog ( RPGDEBUGLEVEL , "libnet:Set signal errror\n");
 			exit (1);
 		}
 #endif
@@ -337,36 +338,36 @@ int newfdent;
 		newfdent = getfdnewentry();
 		/*åȤ롣ΥåȤUNIXɥᥤǡȥ꡼෿åȡ*/
 		if ((rpg_FDS[newfdent] = socket(PF_UNIX, SOCK_STREAM, 0)) < 0) {
-			rpglog(RPGDEBUGLEVEL,"EVENTSV:make socket with UNIX domain and STREAM type\n" );
+			rpglog(RPGDEBUGLEVEL,"libnet:make socket with UNIX domain and STREAM type\n" );
 			perror("socket");
 			return LIBNETMAKESOCERR;
 		}
-		rpglog(RPGDEBUGLEVEL,"EVENTSV:if dont set 0 in saddr it may error on bind()\n" );
+		rpglog(200,"libnet:if dont set 0 in saddr it may error on bind()\n" );
 
 		/*saddrȤ0ˤƤʤȡbind()ǥ顼뤳Ȥ*/
 		bzero((char *)&saddru, sizeof(saddru));
-		rpglog(RPGDEBUGLEVEL,"EVENTSV:set socket name\n" );
+		rpglog(RPGDEBUGLEVEL,"libnet:set socket name\n" );
 
 
 		saddru.sun_family = AF_UNIX;
 		strcpy(saddru.sun_path, service_name);
 	
-		rpglog(RPGDEBUGLEVEL,"EVENTSV:bind socket address\n" );
+		rpglog(RPGDEBUGLEVEL,"libnet:bind socket address\n" );
 		/*åȤ˥ɥ쥹Хɤ롣bind()Ԥʤ褦ǽunlink()
 		ѤơåȤбեõ롣*/
 		unlink(service_name);
 		if (bind(rpg_FDS[newfdent], (struct sockaddr *)&saddru,
 				 sizeof(saddru.sun_family) + strlen(service_name)) < 0){
-			rpglog(RPGDEBUGLEVEL,"EVENTSV:bing error %s\n" , strerror(errno) );
+			rpglog(RPGDEBUGLEVEL,"libnet:bing error %s\n" , strerror(errno) );
 			close (rpg_FDS[newfdent]);
 			perror("bind");
 			return LIBNETSOCBINDERR;
 		}
 	
-		rpglog(RPGDEBUGLEVEL,"EVENTSV:listen to socket\n" );
+		rpglog(RPGDEBUGLEVEL,"libnet:listen to socket\n" );
 		/*listen򥽥åȤФȯԤ*/
 		if (listen(rpg_FDS[newfdent], 1) < 0) {
-			rpglog(RPGDEBUGLEVEL,"EVENTSV:listen error [%s]\n"	 , strerror(errno) );
+			rpglog(RPGDEBUGLEVEL,"libnet:listen error [%s]\n"	 , strerror(errno) );
 			perror("listen");
 			return LIBNETLISSTENERR;
 		}
@@ -393,7 +394,7 @@ int newfdent;
 
 				/*ӥ̾ݡֹ롣*/
 				if ( (serv = getservbyname( service_name , "tcp" ) ) == NULL){
-					rpglog (RPGDEBUGLEVEL , "RPG NET LIB:getservbyname %s error\n" , getservbyname);
+					rpglog (RPGDEBUGLEVEL , "libnet:getservbyname %s error\n" , getservbyname);
 					perror ("getservbyname");
 					return LIBNETGETPORTERR ;
 				}
@@ -406,14 +407,14 @@ int newfdent;
 
 		/*åȤ롣ΥåȤUNIXɥᥤǡȥ꡼෿åȡ*/
 		if ((rpg_FDS[newfdent] = socket(AF_INET, SOCK_STREAM, 0)) < 0) {
-			rpglog (RPGDEBUGLEVEL , "RPG NET LIB:socket error : socket make error \n" );
+			rpglog (RPGDEBUGLEVEL , "libnet:socket error : socket make error \n" );
 			perror("socket");
 			return LIBNETMAKESOCERR;
 		}
 
 		/*åȤ˥ɥ쥹Хɤ롣*/
 		if (bind(rpg_FDS[newfdent], (struct sockaddr *)&saddrt, sizeof(saddrt)) < 0){
-			rpglog ( RPGDEBUGLEVEL , "RPG NET LIB:socket error : socket bind error port [%d]\n" , serv->s_port );
+			rpglog ( 200 , "libnet:socket error : socket bind error port [%d]\n" , serv->s_port );
 			close (rpg_FDS[newfdent]);
 			perror("bind");
 			return LIBNETSOCBINDERR;
@@ -421,12 +422,12 @@ int newfdent;
 
 		/* listen򥽥åȤФȯԤ*/
 		if (listen(rpg_FDS[newfdent], 1) < 0) {
-			rpglog (RPGDEBUGLEVEL , "RPG NET LIB:listen socket error\n");
+			rpglog (RPGDEBUGLEVEL , "libnet:listen socket error\n");
 			perror("listen");
 			return LIBNETLISSTENERR;
 		}
 		servfdT = rpg_FDS[newfdent];
-		rpglog(RPGDEBUGLEVEL , " RPG NET LIB:success init \n");
+		rpglog(RPGDEBUGLEVEL , " libnet:success init \n");
 		return rpg_FDS[newfdent];
 	}else if(type == LIBNET_UDP) {
 		int cnt;
@@ -446,7 +447,7 @@ int newfdent;
 
 				/*ӥ̾ݡֹ롣*/
 				if ( (serv = getservbyname( service_name , "udp" ) ) == NULL){
-					rpglog (RPGDEBUGLEVEL , "RPG NET LIB:getservbyname %s 顼\n" , getservbyname);
+					rpglog (RPGDEBUGLEVEL , "libnet:getservbyname %s 顼\n" , getservbyname);
 					perror ("getservbyname");
 					return LIBNETGETPORTERR ;
 				}
@@ -459,25 +460,25 @@ int newfdent;
 
 		/*åȤ롣ΥåȤIPɥᥤǡDGRAM åȡ*/
 		if ((rpg_FDS[newfdent] = socket(AF_INET, SOCK_DGRAM , 0)) < 0) {
-			rpglog (RPGDEBUGLEVEL , "RPG NET LIB:socket error : make socket error\n" );
+			rpglog (RPGDEBUGLEVEL , "libnet:socket error : make socket error\n" );
 			perror("socket");
 			return LIBNETMAKESOCERR;
 		}
 
 		/*åȤ˥ɥ쥹Хɤ롣*/
 		if (bind(rpg_FDS[newfdent], (struct sockaddr *)&saddrt, sizeof(saddrt)) < 0){
-			rpglog ( RPGDEBUGLEVEL , "RPG NET LIB:socket error : socket bind error port [%d]\n" , serv->s_port );
+			rpglog ( RPGDEBUGLEVEL , "libnet:socket error : socket bind error port [%d]\n" , serv->s_port );
 			close (rpg_FDS[newfdent]);
 			perror("bind");
 			return LIBNETSOCBINDERR;
 		}
 
 		servfdUD = rpg_FDS[newfdent];
-		rpglog(RPGDEBUGLEVEL , " RPG NET LIB:UDP sucsess init\n");
+		rpglog(RPGDEBUGLEVEL , " libnet:UDP sucsess init\n");
 		return rpg_FDS[newfdent];
 
 	}else{
-		rpglog(RPGDEBUGLEVEL , " RPG NET LIB:You miss SOCtype . didnt open server yet[%d]\n" , AF_INET);
+		rpglog(RPGDEBUGLEVEL , " libnet:You miss SOCtype . didnt open server yet[%d]\n" , AF_INET);
 
 	}
 	
@@ -497,7 +498,7 @@ int rpg_tcp_client_open( char * hostname , char * service_name ){
 	}
 	/*åȤκ*/
 	if ((FD = socket(AF_INET, SOCK_STREAM, 0)) < 0) {	
-		rpglog (RPGDEBUGLEVEL , "error make socket\n");
+		rpglog (RPGDEBUGLEVEL , "libnet:error make socket\n");
 		perror("socket");
 		return LIBNETMAKESOCERR;
 	}
@@ -508,7 +509,7 @@ int rpg_tcp_client_open( char * hostname , char * service_name ){
 
 	 /* åȤ̾Ƥ*/
 	if ((hp = gethostbyname(hostname)) == NULL) {
-		rpglog (RPGDEBUGLEVEL , "miss socket name \n");
+		rpglog (RPGDEBUGLEVEL , "libnet:miss socket name \n");
 		perror("No such host");
 		return LIBNETSETHOSTNEMEERR;
 	}
@@ -523,12 +524,12 @@ int rpg_tcp_client_open( char * hostname , char * service_name ){
 
 			/*ӥ̾ݡֹ롣*/
 			if ( (serv = getservbyname( service_name , "tcp" ) ) == NULL){
-				rpglog (RPGDEBUGLEVEL , "RPG NET LIB:getservbyname %s error\n" , getservbyname);
+				rpglog (RPGDEBUGLEVEL , "libnet:libnet:getservbyname %s error\n" , getservbyname);
 				perror ("getservbyname");
 				return LIBNETGETPORTERR ;
 			}
 			addr.sin_port = serv->s_port;
-			rpglog (RPGDEBUGLEVEL ,"param port[%d]\n" , serv->s_port);
+			rpglog (RPGDEBUGLEVEL ,"libnet:param port[%d]\n" , serv->s_port);
 			break;
 		}else{
 			addr.sin_port = htons((short)atoi(service_name));
@@ -538,7 +539,7 @@ int rpg_tcp_client_open( char * hostname , char * service_name ){
 
 	/*СȤ³ߤ롣*/
 	if (connect(FD, (struct sockaddr *)&addr, sizeof(addr)) < 0){
-		rpglog (RPGDEBUGLEVEL , "Try open socket fault [%d]\n" , errno);
+		rpglog (RPGDEBUGLEVEL , "libnet:Try open socket fault [%d]\n" , errno);
 		close(FD);
 		perror("connect");
 		return LIBNETCONECTERR;
@@ -567,7 +568,7 @@ int cnt;
 
 			/*ӥ̾ݡֹ롣*/
 			if ( (serv = getservbyname( service_name , "tcp" ) ) == NULL){
-				rpglog (RPGDEBUGLEVEL , "RPG NET LIB:getservbyname %s error\n" , getservbyname);
+				rpglog (RPGDEBUGLEVEL , "libnet:getservbyname %s error\n" , getservbyname);
 				perror ("getservbyname");
 				return LIBNETGETPORTERR ;
 			}
@@ -592,7 +593,7 @@ int rpg_udp_client_open_port( char * hostname , int port ){
 	}
 	/*åȤκ*/
 	if ((FD = socket(AF_INET, SOCK_DGRAM , 0)) < 0) {	
-		rpglog (RPGDEBUGLEVEL , "miss make socket\n");
+		rpglog (RPGDEBUGLEVEL , "libnet:miss make socket\n");
 		perror("socket");
 		return LIBNETMAKESOCERR;
 	}
@@ -602,7 +603,7 @@ int rpg_udp_client_open_port( char * hostname , int port ){
 
 	 /* åȤ̾Ƥ*/
 	if ((hp = gethostbyname(hostname)) == NULL) {
-		rpglog (RPGDEBUGLEVEL , "input socket name miss\n");
+		rpglog (RPGDEBUGLEVEL , "libnet:input socket name miss\n");
 		perror("No such host");
 		return LIBNETSETHOSTNEMEERR;
 	}
@@ -627,7 +628,7 @@ int rpg_tcp_client_open_port( char * hostname , int port ){
 	}
 	/*åȤκ*/
 	if ((FD = socket(AF_INET, SOCK_STREAM, 0)) < 0) {	
-		rpglog (RPGDEBUGLEVEL , "miss make socket\n");
+		rpglog (RPGDEBUGLEVEL , "libnet:miss make socket\n");
 		perror("socket");
 		return LIBNETMAKESOCERR;
 	}
@@ -637,7 +638,7 @@ int rpg_tcp_client_open_port( char * hostname , int port ){
 
 	 /* åȤ̾Ƥ*/
 	if ((hp = gethostbyname(hostname)) == NULL) {
-		rpglog (RPGDEBUGLEVEL , "miss input socket name\n");
+		rpglog (RPGDEBUGLEVEL , "libnet:miss input socket name\n");
 		perror("No such host");
 		return LIBNETSETHOSTNEMEERR;
 	}
@@ -649,7 +650,7 @@ int rpg_tcp_client_open_port( char * hostname , int port ){
 
 	/*СȤ³ߤ롣*/
 	if (connect(FD, (struct sockaddr *)&addr, sizeof(addr)) < 0){
-		rpglog (RPGDEBUGLEVEL , "try server connection [%d]\n" , errno);
+		rpglog (RPGDEBUGLEVEL , "libnet:try server connection [%d]\n" , errno);
 		close(FD);
 		perror("connect");
 		return LIBNETCONECTERR;
@@ -675,40 +676,40 @@ int rpg_usoc_client_open(char * socketname){
 		clear_fddatabase();
 	}
 	if (strlen(socketname)>MAXPATHLEN){
-		rpglog(RPGDEBUGLEVEL,"RPG NET LIB:sock name over MAXPATHLEN\n");
+		rpglog(RPGDEBUGLEVEL,"libnet:sock name over MAXPATHLEN\n");
 		return LIBNETMAKESOCERR;
 	}
-	rpglog(RPGDEBUGLEVEL,"RPG NET LIB:connect to child process[%s] \n" , socketname);
+	rpglog(RPGDEBUGLEVEL,"libnet:connect to child process[%s] \n" , socketname);
 	/*åȤ롣ΥåȤUNIXɥᥤǡȥ꡼෿åȡ*/
 	if ((FD = socket(PF_UNIX, SOCK_STREAM, 0)) < 0) {
 		perror("socket");
-		rpglog(RPGDEBUGLEVEL , "RPG NET LIB:connecttol:socket error [%s] [%s]\n" ,strerror( errno) , socketname );
+		rpglog(RPGDEBUGLEVEL , "libnet:connecttol:socket error [%s] [%s]\n" ,strerror( errno) , socketname );
 		return LIBNETMAKESOCERR;
 	}
-	rpglog(RPGDEBUGLEVEL,"RPG NET LIB:make socket\n" );
+	rpglog(RPGDEBUGLEVEL,"libnet:make socket\n" );
 
 	/*addrȤ0ˤƤʤȡbind()ǥ顼뤳Ȥ*/
 	bzero((char *)&addr, sizeof(addr));
 
 	/*åȤ̾Ƥ*/
-	rpglog(RPGDEBUGLEVEL,"RPG NET LIB:input sock name\n" );
+	rpglog(RPGDEBUGLEVEL,"libnet:input sock name\n" );
 	addr.sun_family = AF_UNIX;
 	strcpy(addr.sun_path, socketname);
 
 	/*СȤ³ߤ롣*/
-	rpglog(RPGDEBUGLEVEL,"RPG NET LIB:try server open\n" );
+	rpglog(RPGDEBUGLEVEL,"libnet:try server open\n" );
 	if (connect(FD, (struct sockaddr *)&addr,
 			 sizeof(addr.sun_family) + strlen(socketname)) < 0){
 		int cnt;
 		perror("connect");
-		rpglog(RPGDEBUGLEVEL , "RPG NET LIB:connecttol:connect error [%d] [%s]\n" , errno , socketname );
+		rpglog(RPGDEBUGLEVEL , "libnet:connecttol:connect error [%d] [%s]\n" , errno , socketname );
 		sleep (1);
 		/*ԤȤϥȥ饤򤫤ƱưƤΤǽޤ⤷ʤ*/
 		for (cnt = 0 ; cnt < 5 ; cnt++){
 			if (connect(FD, (struct sockaddr *)&addr,
 			 sizeof(addr.sun_family) + strlen(socketname)) < 0){
 				perror("connect");
-				rpglog(RPGDEBUGLEVEL , "RPG NET LIB:connecttol:connect error [%d] [%s]\n" ,
+				rpglog(RPGDEBUGLEVEL , "libnet:connecttol:connect error [%d] [%s]\n" ,
 									errno , socketname );
 				sleep(1);
 			}else{
@@ -717,7 +718,7 @@ int rpg_usoc_client_open(char * socketname){
 		}
 		if (cnt > 4)return (LIBNETCONECTERR);
 	}
-	rpglog(RPGDEBUGLEVEL,"RPG NET LIB:sucess conneck to client\n" );
+	rpglog(RPGDEBUGLEVEL,"libnet:sucess conneck to client\n" );
 
 	rpg_FDS[getfdnewentry()] = FD;
 	return FD;
@@ -730,7 +731,7 @@ int rpg_send_all(char * command ,  char * senddata , int len){
 int cnt;
 
 	for (cnt = 1 ; cnt < rpg_fdnom ; cnt ++){
-		rpglog(RPGDEBUGLEVEL , "rpg_send_all: [%d]-[%d]\n" , cnt , rpg_FDS[cnt]);
+		rpglog(RPGDEBUGLEVEL , "libnet:rpg_send_all: [%d]-[%d]\n" , cnt , rpg_FDS[cnt]);
 		if (rpg_FDS[cnt] > 0){
 			rpg_send(rpg_FDS[cnt],command,senddata,len);
 		}
@@ -746,7 +747,7 @@ int ret , n;
 libnet_send_st send_st;	
 
 	if (FD == 0){
-		rpglog(RPGDEBUGLEVEL , "rpg net lib : Need FD nomber\n");
+		rpglog(RPGDEBUGLEVEL , "libnet: Need FD nomber\n");
 		return LIBNETNOFD;
 	}
 	if (command == NULL ){
@@ -757,7 +758,7 @@ libnet_send_st send_st;
 	}
 	/*udp ΣƣĤȽꤹ*/
 	if ( rpg_UDPAD[test_fd(FD)].sin_port == (int)NULL){
-		rpglog(RPGDEBUGLEVEL , "rpg net lib : this FD not for UDP\n");
+		rpglog(RPGDEBUGLEVEL , "libnet: this FD not for UDP\n");
 		return LIBNETEFAULT;
 	}
 	/*ΣƣĤϿƤ뤫γǧ*/
@@ -786,9 +787,9 @@ libnet_send_st send_st;
 	ret =sendto(FD,  &send_st , sizeof (libnet_send_st), 0, (struct sockaddr *)&rpg_UDPAD[test_fd(FD)], sizeof(rpg_UDPAD[test_fd(FD)]));
 
 	if (ret < 0){
-		rpglog(RPGDEBUGLEVEL , "rpg net lib : head fault send message errno[%n]\n" , errno);
+		rpglog(RPGDEBUGLEVEL , "libnet: head fault send message errno[%n]\n" , errno);
 		if (errno == EPIPE ){
-			rpglog(RPGDEBUGLEVEL , "got socket close\n");
+			rpglog(RPGDEBUGLEVEL , "libnet:got socket close\n");
 			rpgclosefd(FD);
 		}
 		send_st.status = LIBNETSENDERR;
@@ -798,9 +799,9 @@ libnet_send_st send_st;
 	if (senddata != NULL){
 		ret =sendto(FD,  senddata , len , 0, (struct sockaddr *)&rpg_UDPAD[test_fd(FD)], sizeof(rpg_UDPAD[test_fd(FD)]));
 		if (ret < 0){
-			rpglog(RPGDEBUGLEVEL , "rpg net lib : fault send message errno[%n]\n" , errno);
+			rpglog(RPGDEBUGLEVEL , "libnet:fault send message errno[%n]\n" , errno);
 			if (errno == EPIPE ){
-				rpglog(RPGDEBUGLEVEL , "got socket close \n");
+				rpglog(RPGDEBUGLEVEL , "libnet:got socket close \n");
 				rpgclosefd(FD);
 			}
 			send_st.status = LIBNETHEADSENDERR;
@@ -819,7 +820,7 @@ int ret , n ;
 libnet_send_st send_st;	
 
 	if (FD == 0){
-		rpglog(RPGDEBUGLEVEL , "rpg net lib : need FD nom tu operate\n");
+		rpglog(RPGDEBUGLEVEL , "libnet:need FD nom tu operate\n");
 		return LIBNETNOFD;
 	}
 	if (command == NULL ){
@@ -860,9 +861,9 @@ libnet_send_st send_st;
 	/*إåΰ*/
 	ret = write ( FD , &send_st , sizeof (libnet_send_st));
 	if (ret < 0){
-		rpglog(RPGDEBUGLEVEL , "rpg net lib : head faulr send errno[%n]\n" , errno);
+		rpglog(RPGDEBUGLEVEL , "libnet:head faulr send errno[%n]\n" , errno);
 		if (errno == EPIPE ){
-			rpglog(RPGDEBUGLEVEL , "got socket close \n");
+			rpglog(RPGDEBUGLEVEL , "libnet:got socket close \n");
 			rpgclosefd(FD);
 		}
 		send_st.status = LIBNETSENDERR;
@@ -872,9 +873,9 @@ libnet_send_st send_st;
 	if (senddata != NULL){
 		ret = write ( FD ,senddata , len);
 		if (ret < 0){
-			rpglog(RPGDEBUGLEVEL , "rpg net lib : fault send errno[%n]\n" , errno);
+			rpglog(RPGDEBUGLEVEL , "libnet:fault send errno[%n]\n" , errno);
 			if (errno == EPIPE ){
-				rpglog(RPGDEBUGLEVEL , "got socket close\n");
+				rpglog(RPGDEBUGLEVEL , "libnet:got socket close\n");
 				rpgclosefd(FD);
 			}
 			send_st.status = LIBNETHEADSENDERR;
@@ -985,19 +986,19 @@ int read_packet(int FD	 , int requestlen , int *read_len , char * buf , int bufs
 				return stat;
 			}
 			if ((ret = poll (&pollFD , 1 , timeout))< 0){
-				rpglog(RPGDEBUGLEVEL , " pollerror [%d]\n" , errno);
+				rpglog(RPGDEBUGLEVEL , "libnet: pollerror [%d]\n" , errno);
 				free (tmpbuf);
 				return (stat);
 			} 
 			if ((pollFD.revents & (0x0001 | 0x0002))== 0){
-				rpglog(RPGDEBUGLEVEL , " pollerror [%d]\n" , errno);
+				rpglog(RPGDEBUGLEVEL , "libnet: pollerror [%d]\n" , errno);
 				free (tmpbuf);
 				return (stat);
 			}
 			/*ɤ߹ߤγ*/
 			ret = read (FD ,tmpbuf ,lessofbuf );
 			if (ret< 0){
-				rpglog(RPGDEBUGLEVEL , "read error [%d]\n" , errno);
+				rpglog(RPGDEBUGLEVEL , "libnet:read error [%d]\n" , errno);
 				free (tmpbuf);
 				return (stat);
 			}
@@ -1005,11 +1006,11 @@ int read_packet(int FD	 , int requestlen , int *read_len , char * buf , int bufs
 		}
 		return (stat);
 	}else{
-		rpglog(  RPGDEBUGLEVEL  ,"not enouf data\n");
+		rpglog(  RPGDEBUGLEVEL  ,"libnet:not enouf data\n");
 
 	}
 	/*ǡƤʤ硢ȥ饤ߥॢʬɤ߹ߤ»ܤơ*/
-	rpglog(  RPGDEBUGLEVEL  , "read_packet:if not have data . try to read (retrytime * timeout) \n" );
+	rpglog(  RPGDEBUGLEVEL  , "libnet:read_packet:if not have data . try to read (retrytime * timeout) \n" );
 	return LIBNETERR;
 	
 
@@ -1033,7 +1034,7 @@ int RPG_Poll( char * command , char * data , int buf_length , int *length , int
 	int cnt2;
 
 	*length = 0;
-
+	bzero (command,COMMANDLEN);
 	for (cnt = 0 ; cnt < fdlim.rlim_cur ; cnt ++){
 		if (rpg_FDS[cnt] != 0){
 			s_Poll[i].events = POLLIN;
@@ -1056,13 +1057,13 @@ int RPG_Poll( char * command , char * data , int buf_length , int *length , int
 				/*UNIXåȤ³׵*/
 				if ((s_Poll[cnt].fd ==	servfdU) && (servfdU != 0)){
 					struct sockaddr_un	  caddr;
-					rpglog(RPGDEBUGLEVEL , "got connect ion request \n");
+					rpglog(RPGDEBUGLEVEL , "libnet:got connect ion request \n");
 					len = sizeof(caddr);
 					new_fd = getfdnewentry();
 					if ((rpg_FDS[new_fd] = accept(s_Poll[cnt].fd ,	
 						(struct sockaddr *)&caddr, &len)) < 0) {
 						perror("accept");
-						rpglog(RPGDEBUGLEVEL , "acept error WHY!![%d]\n" , errno);
+						rpglog(RPGDEBUGLEVEL , "libnet:acept error WHY!![%d]\n" , errno);
 						if (rpg_FDS[new_fd] > 0)rpgclosefd(rpg_FDS[new_fd]);
 						return LIBNETCONNECTIONERROR;/*exit(1);*/
 					}
@@ -1072,21 +1073,21 @@ int RPG_Poll( char * command , char * data , int buf_length , int *length , int
 					*resfd = rpg_FDS[new_fd];
 					*length = sizeof (int);
 					/*׵ƥץȤ饳ͥȤȤ֤*/
-					rpglog(RPGDEBUGLEVEL , "return that have  connect [%d]-[%d]\n"
+					rpglog (RPGDEBUGLEVEL , "libnet:return that have  connect [%d]-[%d]\n"
 					, new_fd , rpg_FDS[new_fd]);
 					return (LIBNETCONNECTREQUESTU);
 				}
 				/*³׵ץץȤơƣĤϿ*/
 				if ((s_Poll[cnt].fd ==	servfdT) && (servfdT != 0)){
 					struct sockaddr_in	  caddr;
-					rpglog(RPGDEBUGLEVEL , "conection request\n");
+					rpglog (RPGDEBUGLEVEL , "libnet:conection request\n");
 					len = sizeof(caddr);
 					new_fd = getfdnewentry();
 					/*ץȤ򤹤*/
 					if ((rpg_FDS[new_fd] = accept(s_Poll[cnt].fd ,	
 						(struct sockaddr *)&caddr, &len)) < 0) {
 						/*ԤФƼԤ֤*/
-						rpglog(RPGDEBUGLEVEL , "acept error WHY!![%d]\n" , errno);
+						rpglog (RPGDEBUGLEVEL , "libnet:acept error WHY!![%d]\n" , errno);
 						if (rpg_FDS[new_fd] > 0)rpgclosefd(rpg_FDS[new_fd]);
 						return LIBNETCONNECTIONERROR;
 					}
@@ -1096,13 +1097,13 @@ int RPG_Poll( char * command , char * data , int buf_length , int *length , int
 					/*³夹ˣΣţԣңУǤΥץ׵Ǥ뤳Ȥ򼨤ѥåȤϤ*/
 					if (ret < 0 ){
 						/*ǡʤȤϥͥ󥨥顼Ȥƽ*/
-						rpglog(RPGDEBUGLEVEL , "it must have packet[%d]-[%d]\n" , ret , timeout);
+						rpglog (RPGDEBUGLEVEL , "libnet:it must have packet[%d]-[%d]\n" , ret , timeout);
 						rpgclosefd (rpg_FDS[new_fd]);
 						return LIBNETCONNECTIONDATAERR;
 					}
 					/*Ƥǧ*/
 					if (memcmp (data , LIBNETASSEPT , strlen(LIBNETASSEPT))!=0){
-						rpglog(RPGDEBUGLEVEL , "test is is true\n");
+						rpglog (RPGDEBUGLEVEL , "libnet:test is is true\n");
 						rpgclosefd (rpg_FDS[new_fd]);
 						return LIBNETCONNECTIONDATAERR;
 					}
@@ -1112,7 +1113,7 @@ int RPG_Poll( char * command , char * data , int buf_length , int *length , int
 					*resfd = rpg_FDS[new_fd];
 					*length = sizeof (int);
 					memcpy (command , LIBNETCONNECTREQ , COMMANDLEN);
-					rpglog(RPGDEBUGLEVEL , "return connect if it was sucsess[%d]-[%d]\n"
+					rpglog (RPGDEBUGLEVEL , "libnet:return connect if it was sucsess[%d]-[%d]\n"
 					, new_fd , rpg_FDS[new_fd]);
 					return LIBNETCONNECTREQUESTT;
 				}
@@ -1172,7 +1173,7 @@ int RPG_Poll( char * command , char * data , int buf_length , int *length , int
 				/*ɣĤäȤϥơ˿ä*/
 				if (++rpg_IDSR[cnt2] != revint((char*)&packet_head.ID)){
 					stat = LIBNETNOIDCONTINU;
-					rpglog(RPGDEBUGLEVEL , "The ID was fault[%d]-[%d]\n" , 
+					rpglog (RPGDEBUGLEVEL , "libnet:The ID was fault[%d]-[%d]\n" , 
 						rpg_IDSR[cnt2] ,revint((char*)&packet_head.ID));
 					rpg_IDSR[cnt2] = revint((char*)&packet_head.ID);
 				}
@@ -1365,8 +1366,8 @@ char filename[LOGBUFFSIZE];
 }
 
 int rpg_logclose(){
-
-
+	rpg_gamelog(-1,"");
+	return RPG_OK;
 }
 
 
@@ -1377,7 +1378,7 @@ int rpg_loginit( char * pname  , char * sockname){
 		if ( logconnect == 0){/*⤷Ф³Ƥʤä³򤹤*/
 			if ( rpglogfd == 0){
 				if ( (ret = rpg_usoc_client_open(sockname)) < 0){
-					rpglog (RPGDEBUGLEVEL , "cant connect log server\n");
+					rpglog (RPGDEBUGLEVEL , "libnet:cant connect log server\n");
 					return ret;
 				}
 				rpglogfd = ret;
@@ -1388,12 +1389,12 @@ int rpg_loginit( char * pname  , char * sockname){
 			}
 			logconnect = 1;
 		}else{
-			rpglog(RPGDEBUGLEVEL , "log server already connected \n");
+			rpglog (RPGDEBUGLEVEL , "libnet:log server already connected \n");
 			/*ФΣƣĤ֤*/
 			return rpglogfd;
 		}
 	}else{
-		rpglog(RPGDEBUGLEVEL , "log server sockname not abuveable\n");
+		rpglog (RPGDEBUGLEVEL , "libnet:log server sockname not abuveable\n");
 	}
 	return ret;
 }
@@ -1404,7 +1405,7 @@ int loginit( char * pname ){
 		if ( logconnect == 0){/*⤷Ф³Ƥʤä³򤹤*/
 			if ( rpglogfd == 0){
 				if ( (ret = rpg_usoc_client_open(LIBNETLOGSOCNAME)) < 0){
-					rpglog (RPGDEBUGLEVEL , "cant connect log server\n");
+					rpglog (RPGDEBUGLEVEL , "libnet:cant connect log server\n");
 					return ret;
 				}
 				rpglogfd = ret;
@@ -1415,7 +1416,7 @@ int loginit( char * pname ){
 			}
 			logconnect = 1;
 		}else{
-			rpglog(RPGDEBUGLEVEL , "log server already connected \n");
+			rpglog(RPGDEBUGLEVEL , "libnet:log server already connected \n");
 			/*ФΣƣĤ֤*/
 			return rpglogfd;
 		}
@@ -1449,7 +1450,7 @@ va_list ap;
 	memset (filename , (int)NULL ,sizeof(int) +LOGBUFFSIZE);
 	/*֤Υå*/
 	if ( time (&timeb) < 0){
-		printf ("cant got time[%s]\n" , strerror (errno));
+		printf ("libnet:cant got time[%s]\n" , strerror (errno));
 	}else{
 		/*֤򥻥åȤ*/
 		timebuf = localtime(&timeb);
@@ -1475,18 +1476,25 @@ va_list ap;
 			return (ret);
 		}
 	}
+	n=1;
 	/*ФФ򤹤*/
 	if( *(char*)&n ){
 		/*⡼륨ǥ*/
-		memcpy (filename ,(char *)&DBlev , sizeof (int));
+		revcpy ((char *)&DBlev , (char *)filename,sizeof(int));	/*ץΣɣ*/
 	}else{
 		/*⤷ӥåǥ*/
-		revcpy ((char *)&DBlev , (char *)filename,sizeof(int));	/*ץΣɣ*/
+		memcpy (filename ,(char *)&DBlev , sizeof (int));
 	}
 	if (rpglogfd > 0){
+#if 0
 		strncpy (&filename[sizeof (int)] , errerbufffer , strlen (errerbufffer));
 		strcat (&filename[sizeof (int)] , rpgPname);	/*襻ơۡˤʤǽ*/
-		strcat (&filename[sizeof (int)] , tmpbuf );
+#endif
+		strncpy (&filename[sizeof (int)] , rpgPname,LOGBUFFSIZE-1);	
+		strcat (&filename[sizeof (int)] , ":" );
+		if (LOGBUFFSIZE-strlen(rpgPname)-1>0){
+			strncat (&filename[sizeof (int)] , tmpbuf ,LOGBUFFSIZE-strlen(rpgPname)-1);
+		}
 		ret = rpg_send(rpglogfd , RPGLOGREQ , filename	, sizeof(int)+strlen (&filename[sizeof (int)]));
 	}else{
 		return LIBNETNOFD;
@@ -1556,7 +1564,7 @@ static int opflag = 0;
 	/*ͭΥå*/
 	adder = shmat ( ctlshmid , NULL , (int)NULL);
 	if (adder < 0){
-		rpglog(RPGDEBUGLEVEL , "faule attatch shm[%s]\n" , strerror(errno));
+		rpglog(RPGDEBUGLEVEL , "libnet:faule attatch shm[%s]\n" , strerror(errno));
 		adder = NULL;
 		return (RPG_shmunit * )(LIBNETSHMATTACHERR);
 		/*ͭؤΥåʤ*/
@@ -1608,14 +1616,14 @@ char *	RPG_shmctl_init(shment * shmentry , int entrynom  , int *ctlshmid ){
 		ret3 = RPG_shmctl_addentry( shmentry[cnt].shmNO, shmentry[cnt].size );
 		if ((int)(ret3) < (int)NULL){
 			char * buf = NULL;
-			rpglog (RPGDEBUGLEVEL , "shmaddentry error [%d] [%s]\n" , ret3 ,(char *) rpg_net_perror((int)ret3 , buf));
+			rpglog (RPGDEBUGLEVEL , "libnet:shmaddentry error [%d] [%s]\n" , ret3 ,(char *) rpg_net_perror((int)ret3 , buf));
 			PRG_shmctl_destroy();
 			return (ret3);
 		}else{
 			memset ((char *)ret3,0,shmentry[cnt].size);
 		}
 	}
-	rpglog(RPGDEBUGLEVEL , "RPG_shmctl_init end [%d]\n" , RPG_shm);
+	rpglog (RPGDEBUGLEVEL , "libnet:RPG_shmctl_init end [%d]\n" , RPG_shm);
 	return ((char *)RPG_shm);
 }
 /*ͭΥȥɲáʺ*/
@@ -1674,7 +1682,7 @@ char * adder;
 	}
 	adder = shmat ( RPG_shm[shmNO].shm_id , NULL , (int)NULL);
 	if (adder < 0){
-		rpglog(RPGDEBUGLEVEL , "fault atatch shm[%s]\n" , strerror(errno));
+		rpglog (RPGDEBUGLEVEL , "libnet:fault atatch shm[%s]\n" , strerror(errno));
 		adder = NULL;
 		return (char *)(LIBNETSHMATTACHERR);
 	}
@@ -1718,11 +1726,11 @@ static RPG_shmunit * ctladder= NULL;
 void  RPG_shm_all_detach(){
 	int cnt;
 	RPG_shmunit * ctladder;
-	rpglog(RPGDEBUGLEVEL ,"RPG_shm_all_detach start\n");
+	rpglog (RPGDEBUGLEVEL , "libnet:RPG_shm_all_detach start\n");
 	ctladder = RPG_shm_all_attach((int)NULL);
 	if (ctladder == NULL)return; 
 	for (cnt = 0 ; cnt < LIBNETSHMIDMAX ; cnt++)
-		rpglog(RPGDEBUGLEVEL ,"RPG_shm_all_detach[%d][%d]\n" , cnt , ctladder[cnt].adder);
+		rpglog (RPGDEBUGLEVEL , "libnet:RPG_shm_all_detach[%d][%d]\n" , cnt , ctladder[cnt].adder);
 		if (ctladder[cnt].adder != NULL)shmdt(ctladder[cnt].adder);
 	if (RPG_shm != NULL)shmdt(RPG_shm);
 	RPG_shm = NULL;
@@ -1734,13 +1742,13 @@ void  RPG_shm_all_detach(){
 void  RPG_shm_detach(){
 	int cnt;
 	RPG_shmunit * ctladder;
-	rpglog(RPGDEBUGLEVEL ,"RPG_shm_detach start\n");
+	rpglog (RPGDEBUGLEVEL , "libnet:RPG_shm_detach start\n");
 	ctladder = RPG_shm_init((int)NULL);
 	if (ctladder == NULL){
 		return;
 	}
 	for (cnt = 0 ; cnt < LIBNETSHMIDMAX ; cnt++){
-		rpglog(RPGDEBUGLEVEL ,"RPG_shm_detach[%d][%d]\n" , cnt , ctladder[cnt].adder);
+		rpglog (RPGDEBUGLEVEL , "libnet:RPG_shm_detach[%d][%d]\n" , cnt , ctladder[cnt].adder);
 		if (ctladder[cnt].adder != NULL){
 			shmdt(ctladder[cnt].adder);
 			ctladder[cnt].adder = NULL;
@@ -1749,6 +1757,140 @@ void  RPG_shm_detach(){
 		}
 	}
 }
+/**********************************************************
+ͭmmapؤ
+
+static 
+
+char * rpg_mopen(char * filepath );
+
+void rpg_memclose (char *filepath );
+**********************************************************/
+libnet_mmaps libnet_mmap[MAXMEMNOM];
+
+static int rpgmmatnom = 0;
+char * rpg_mopen(char * filepath ){
+int nom = -1;
+struct stat statbuf;
+int ret,cnt ;
+
+	/*ǤϿƤ餽ΣģģţҤ֤*/
+	for (cnt = 0 ; cnt < rpgmmatnom;cnt++){
+		if (strncmp ( filepath , libnet_mmap[cnt].fpath , MAXPATHLEN)==0){
+			rpglog (200 , "libnet:rpg_mopen:alredy opend \n");
+			return libnet_mmap[cnt].addr;
+		}
+	}
+	for (cnt = 0 ; cnt < rpgmmatnom;cnt++){
+		if (libnet_mmap[cnt].addr <= 0){
+			nom=cnt;
+			break;
+		}
+	}
+	if (nom == -1 ){
+		nom = ++rpgmmatnom;
+	}
+	/*ͤΤĹեѥӽ*/
+	if (strlen (filepath) > MAXPATHLEN){
+		rpglog (RPGDEBUGLEVEL , "libnet:rpg_mopen:too long file path\n");
+		return NULL;
+	}
+	/*꡼ĥդե򥪡ץ󤹤*/
+	libnet_mmap[nom].FD=open (filepath , O_RDWR );
+	if (libnet_mmap[nom].FD ==1 ){
+		rpglog (RPGDEBUGLEVEL , "libnet:rpg_mopen:cant open file[%s]\n" , filepath);
+		return NULL;
+	}
+	/*եΥåȤ*/
+	ret = fstat (libnet_mmap[nom].FD , &statbuf );
+	if (ret < 0){
+		rpglog (RPGDEBUGLEVEL , "libnet:rpg_mopen:cant get stat of file[%s]\n" , filepath);
+		return NULL;
+	}
+	libnet_mmap[nom].length=statbuf.st_size;
+	/*åȤ򸵤˥ե륵礭ǣͣͣФstatbuf.st_size */
+#ifdef _POSIX_MAPPED_FILES
+	libnet_mmap[nom].addr = 
+		mmap (NULL,statbuf.st_size,PROT_WRITE|PROT_READ,MAP_SHARED,libnet_mmap[nom].FD,0);
+#endif
+	if (libnet_mmap[nom].addr == (void *)-1){
+		rpglog (RPGDEBUGLEVEL , "libnet:rpg_mopen:mmap error errno[%d]\n",errno);
+		return NULL;
+	}
+	return libnet_mmap[nom].addr ;
+}
+
+void rpg_mclose(char * filepath){
+int ret,cnt ;
+	/*Ͽ򸡺Ƥ*/
+    for (cnt = 0 ; cnt < rpgmmatnom;cnt++){
+        if (strncmp ( filepath , libnet_mmap[cnt].fpath , MAXPATHLEN)==0){
+            rpglog (200 , "libnet:rpg_mclose:found entry \n");
+#ifdef _POSIX_MAPPED_FILES
+            ret = munmap (libnet_mmap[cnt].addr ,libnet_mmap[cnt].length );
+			if (ret < 0)rpglog (RPGDEBUGLEVEL , "libnet:rpg_mclose:munmap error \n");
+#endif
+			libnet_mmap[cnt].addr=NULL;
+			libnet_mmap[cnt].FD=0;
+			libnet_mmap[cnt].length=0;
+			bzero (libnet_mmap[cnt].fpath , MAXPATHLEN);
+			return ;
+        }
+    }
+	/*ϿƤʤХ顼åϤ*/
+	rpglog (RPGDEBUGLEVEL , "libnet:rpg_mclose:cant find map to close\n");
+}
+int rpg_mlength(char * filepath){
+int ret,cnt ;
+	/*Ͽ򸡺Ƥ*/
+    for (cnt = 0 ; cnt < rpgmmatnom;cnt++){
+        if (strncmp ( filepath , libnet_mmap[cnt].fpath , MAXPATHLEN)==0){
+            rpglog (200 , "libnet:rpg_mlength:found entry \n");
+			return libnet_mmap[cnt].length;
+        }
+    }
+	/*ϿƤʤХ顼åϤ*/
+	rpglog (RPGDEBUGLEVEL , "libnet:rpg_mclose:cant find map to close\n");
+	return RPG_NG;
+}
+
+void rpg_mallclose(){
+int ret,cnt ;
+
+    for (cnt = 0 ; cnt < rpgmmatnom;cnt++){
+        if (strlen (libnet_mmap[cnt].fpath)>0 ){
+            rpglog (200 , "libnet:rpg_mclose:found entry \n");
+#ifdef _POSIX_MAPPED_FILES
+            ret = munmap (libnet_mmap[cnt].addr ,libnet_mmap[cnt].length );
+			if (ret < 0)rpglog (RPGDEBUGLEVEL , "libnet:rpg_mclose:munmap error \n");
+#endif
+			libnet_mmap[cnt].addr=NULL;
+			libnet_mmap[cnt].FD=0;
+			libnet_mmap[cnt].length=0;
+			bzero (libnet_mmap[cnt].fpath , MAXPATHLEN);
+        }
+    }
+
+}
+
+void rpg_msync(char * filepath){
+int ret,cnt ;
+    for (cnt = 0 ; cnt < rpgmmatnom;cnt++){
+        if (strncmp ( filepath , libnet_mmap[cnt].fpath , MAXPATHLEN)==0){
+            rpglog (200 , "libnet:rpg_msync:found entry \n");
+#ifdef _POSIX_MAPPED_FILES
+#ifdef _POSIX_SYNCHRONIZED_IO
+            ret = msync (libnet_mmap[cnt].addr ,libnet_mmap[cnt].length  , MS_ASYNC);
+			if (ret < 0)rpglog (RPGDEBUGLEVEL , "libnet:rpg_mclose:munmap error \n");
+#endif
+#endif
+
+			return ;
+        }
+    }
+	/*ϿƤʤХ顼åϤ*/
+	rpglog (RPGDEBUGLEVEL , "libnet:rpg_msync:cant find map to close\n");
+}
 
 /**********************************************************
 ơط
