@@ -49,6 +49,13 @@
 #include <locale.h>
 #include <zlib.h>
 #include <zconf.h>
+#define _GNU_SOURCE
+#include <getopt.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
+#include <sys/mman.h>
+
 /*
 #include "rpgnet.h"
 */
@@ -74,6 +81,9 @@
 #ifndef RPG_OK
 #	define RPG_OK		1
 #endif
+#ifndef RPG_NG
+#	define RPG_NG		0
+#endif
 
 #define LIBNET
 #define LIBNET
@@ -158,7 +168,7 @@
 #define LIBNETPHEADER			"NRPGHEAD"	/*ѥåȥإå*/
 #define LIBNETASSEPT			"LIBNETASSEPT"	 
 #define LIBNETCONNECTREQ		"CONNECTREQ"	/*³׵*/
-#define POLLTIMEUP          "PALLTIMEUP"            /**/
+#define POLLTIMEUP          	"POLLTIMEUP"            /**/
 #define LIBNETWTIMEUP2			"LIBNETIMUP"
 /*		ʸ󤬤뤳,
 		length
@@ -625,6 +635,7 @@ int rpglog(int level , char * buf , ... );
 	   #define RPGNOTICELEVEL	60	/* normal but significant condition */
 	   #define RPGINFOLEVEL		70	/* informational					*/
 	   #define RPGDEBUGLEVEL	80	/* debug-level messages				*/
+	
 
 
 /**************************************************************************/
@@ -869,7 +880,6 @@ RPG_shmunit * RPG_shm_all_attach(int ctlshmid );
 
 */
 char * RPG_shm_attach(int shmNO);
-/**************************************************************************/
 
 
 /**************************************************************************/
@@ -891,7 +901,6 @@ char * RPG_shm_attach(int shmNO);
 
 */
 void  RPG_shm_detach(void);
-/**************************************************************************/
 
 /**************************************************************************/
 /*	
@@ -911,6 +920,92 @@ void  RPG_shm_detach(void);
 */
 void  RPG_shm_all_detach(void);
 
+/**************************************************************************/
+/*	
+		ͭ
+
+	char * rpg_mopen(char * filepath );
+	ǥץ򤷤
+	void rpg_msync(char * filepath);
+	ǥեȿǤ
+	void rpg_mallclose();
+	void rpg_mclose(char * filepath);
+	ǥ
+
+*/
+#define MAXMEMNOM 100
+
+typedef struct{
+	char fpath[MAXPATHLEN];
+	int  FD;
+	int length;
+	char *addr;
+}libnet_mmaps;
+
+/**************************************************************************/
+/*	
+			ͭΥեؤΥեå
+	
+		ޥåפ줿ƤեȿǤ
+		Ϥ֤롢
+		
+
+	
+		char * filepath
+								mmmapեѥ
+
+	͡
+		̵
+
+*/
+void rpg_msync(char * filepath);
+/**************************************************************************/
+/*	
+			ޥåפ줿
+	
+		ޥåפ줿Υޥå
+	
+	
+		̵
+
+	͡
+		̵
+
+*/
+void rpg_mallclose();
+/**************************************************************************/
+/*		
+			ޥåפ줿Υ
+	
+		ǻꤵ줿եѥΥޥåפ줿
+		ƥޥåפ
+
+	
+		char * filepath
+								mmmapեѥ
+
+	͡
+		̵
+*/
+void rpg_mclose(char * filepath);
+/**************************************************************************/
+/*	
+			ե˥ޥåפ
+	
+		ե˥ޥåפ
+		ˤǤ˥ޥåפ줿եѥ
+		ƥޥåפϤˡΥޥåפ줿Υݥ󥿤֤
+
+	
+		char * filepath
+								mmmapեѥ
+
+	͡
+		char * 			Ÿ줿꡼ؤΥݥ
+
+*/
+char * rpg_mopen(char * filepath );
+/**************************************************************************/
 
 
 /**********************************************************
